@@ -153,11 +153,11 @@ def transl2(x, y=None):
     :type x: float
     :param y: translation along Y-axis
     :type y: float
-    :return: SE(2) transform matrix or the translation elements of a homogeneous transform
-    :rtype: ndarray(3,3)
+    :return: SE(2) transform matrix or the translation elements of a homogeneous
+        transform :rtype: ndarray(3,3)
 
-    - ``T = transl2([X, Y])`` is an SE(2) homogeneous transform (3x3) representing a
-      pure translation.
+    - ``T = transl2([X, Y])`` is an SE(2) homogeneous transform (3x3)
+      representing a pure translation.
     - ``T = transl2( V )`` as above but the translation is given by a 2-element
       list, dict, or a numpy array, row or column vector.
 
@@ -193,20 +193,23 @@ def transl2(x, y=None):
         function.
     """
 
-    if base.isscalar(x):
+    if base.isscalar(x) and base.isscalar(y):
+        # (x, y) -> SE(2)
         t = np.r_[x, y]
-        T = np.identity(3, dtype=t.dtype)
-        T[:2, 2] = t
-        return T
     elif base.isvector(x, 2):
-        T = np.identity(3)
-        T[:2, 2] = base.getvector(x, 2)
-        return T
+        # R2 -> SE(2)
+        t = base.getvector(x, 2)
     elif base.ismatrix(x, (3, 3)):
+        # SE(2) -> R2
         return x[:2, 2]
     else:
         raise ValueError('bad argument')
 
+    if t.dtype != 'O':
+        t = t.astype('float64')
+    T = np.identity(3, dtype=t.dtype)
+    T[:2, 2] = t
+    return T
 
 def ishom2(T, check=False):
     """
@@ -616,7 +619,7 @@ def trinterp2(start, end, s=None):
         return ValueError('Argument must be SO(2) or SE(2)')
 
 
-def trprint2(T, label=None, file=sys.stdout, fmt='{:8.2g}', unit='deg'):
+def trprint2(T, label=None, file=sys.stdout, fmt='{:.3g}', unit='deg'):
     """
     Compact display of SE(2) or SO(2) matrices
 
@@ -651,6 +654,14 @@ def trprint2(T, label=None, file=sys.stdout, fmt='{:8.2g}', unit='deg'):
         >>> from spatialmath.base import *
         >>> T = transl2(1,2) @ trot2(0.3)
         >>> trprint2(T, file=None, label='T')
+        >>> trprint2(T, file=None, label='T', fmt='{:8.4g}')
+
+
+    .. notes::
+
+        - Default formatting is for compact display of data
+        - For tabular data set ``fmt`` to a fixed width format such as
+          ``fmt='{:.3g}'``
 
     :seealso: trprint
     """
@@ -667,7 +678,9 @@ def trprint2(T, label=None, file=sys.stdout, fmt='{:8.2g}', unit='deg'):
     angle = math.atan2(T[1, 0], T[0, 0])
     if unit == 'deg':
         angle *= 180.0 / math.pi
-    s += ' {} {}'.format(_vec2s(fmt, [angle]), unit)
+        s += ' {}°'.format(_vec2s(fmt, [angle]))
+    else:
+        s += ' {} rad'.format(_vec2s(fmt, [angle]))
 
     if file:
         print(s, file=file)
