@@ -17,6 +17,7 @@ import sys
 import math
 from math import sin, cos
 import numpy as np
+import scipy as sp
 from spatialmath import base
 from collections.abc import Iterable
 
@@ -295,9 +296,13 @@ def transl(x, y=None, z=None):
     elif base.isvector(x, 3):
         t = base.getvector(x, 3, out='array')
     elif base.ismatrix(x, (4, 4)):
+        # SE(3) -> R3
         return x[:3, 3]
     else:
         raise ValueError('bad argument')
+
+    if t.dtype != 'O':
+        t = t.astype('float64')
     
     T = np.identity(4, dtype=t.dtype)
     T[:3, 3] = t
@@ -657,7 +662,89 @@ def angvec2tr(theta, v, unit='rad'):
     """
     return base.r2t(angvec2r(theta, v, unit=unit))
 
+# ---------------------------------------------------------------------------------------#
 
+def exp2r(w):
+    """
+    Create an SO(3) rotation matrix from exponential coordinates
+
+    :param w: exponential coordinate vector
+    :type w: array_like(3)
+    :return: SO(3) rotation matrix
+    :rtype: ndarray(3,3)
+    :raises ValueError: bad arguments
+
+    ``exp2r(w)`` is an SO(3) orthonormal rotation matrix
+    equivalent to a rotation of :math:`\| w \|` about the vector :math:`\hat{w}`.
+
+    If ``w`` is zero then result is the identity matrix.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> eulervec2r([0.3, 0, 0])  # rotx(0.3)
+        >>> angvec2r([0, 0, 0])      # rotx(0)
+
+    .. note:: Exponential coordinates are also known as an Euler vector
+
+    :seealso: :func:`~angvec2r`, :func:`~tr2angvec`
+
+    :SymPy: not supported
+    """
+    if not base.isvector(w, 3):
+        raise ValueError("Arguments must be a 3-vector")
+
+    v, theta = base.unitvec_norm(w)
+
+    if theta is None:
+        return np.eye(3)
+
+    # Rodrigue's equation
+
+    sk = base.skew(v)
+    R = np.eye(3) + math.sin(theta) * sk + (1.0 - math.cos(theta)) * sk @ sk
+    return R
+
+def exp2tr(w):
+    """
+    Create an SE(3) pure rotation matrix from exponential coordinates
+
+    :param w: exponential coordinate vector
+    :type w: array_like(3)
+    :return: SO(3) rotation matrix
+    :rtype: ndarray(3,3)
+    :raises ValueError: bad arguments
+
+    ``exp2r(w)`` is an SO(3) orthonormal rotation matrix
+    equivalent to a rotation of :math:`\| w \|` about the vector :math:`\hat{w}`.
+
+    If ``w`` is zero then result is the identity matrix.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> eulervec2r([0.3, 0, 0])  # rotx(0.3)
+        >>> angvec2r([0, 0, 0])      # rotx(0)
+
+    .. note:: Exponential coordinates are also known as an Euler vector
+
+    :seealso: :func:`~angvec2r`, :func:`~tr2angvec`
+
+    :SymPy: not supported
+    """
+    if not base.isvector(w, 3):
+        raise ValueError("Arguments must be a 3-vector")
+
+    v, theta = base.unitvec_norm(w)
+
+    if theta is None:
+        return np.eye(4)
+
+    # Rodrigue's equation
+
+    sk = base.skew(v)
+    R = np.eye(3) + math.sin(theta) * sk + (1.0 - math.cos(theta)) * sk @ sk
+    return base.r2t(R)
 # ---------------------------------------------------------------------------------------#
 def oa2r(o, a=None):
     """
@@ -948,7 +1035,7 @@ def tr2rpy(T, unit='rad', order='zyx', check=False):
                 rpy[2] = math.atan2(R[2, 1], R[1, 1])   # R+Y
             else:
                 rpy[2] = -math.atan2(R[1, 0], R[2, 0])   # R-Y
-            rpy[1] = math.asin(R[0, 2])
+            rpy[1] = math.asin(np.clip(R[0, 2], -1.0, 1.0))
         else:
             rpy[0] = -math.atan2(R[0, 1], R[0, 0])
             rpy[2] = -math.atan2(R[1, 2], R[2, 2])
@@ -973,7 +1060,7 @@ def tr2rpy(T, unit='rad', order='zyx', check=False):
                 rpy[2] = -math.atan2(R[0, 1], R[0, 2])  # R-Y
             else:
                 rpy[2] = math.atan2(-R[0, 1], -R[0, 2])  # R+Y
-            rpy[1] = -math.asin(R[2, 0])
+            rpy[1] = -math.asin(np.clip(R[2, 0], -1.0, 1.0))
         else:
             rpy[0] = math.atan2(R[2, 1], R[2, 2])  # R
             rpy[2] = math.atan2(R[1, 0], R[0, 0])  # Y
@@ -997,7 +1084,7 @@ def tr2rpy(T, unit='rad', order='zyx', check=False):
                 rpy[2] = -math.atan2(R[2, 0], R[0, 0])   # R-Y
             else:
                 rpy[2] = math.atan2(-R[2, 0], -R[2, 1])   # R+Y
-            rpy[1] = -math.asin(R[1, 2])    # P
+            rpy[1] = -math.asin(np.clip(R[1, 2], -1.0, 1.0))    # P
         else:
             rpy[0] = math.atan2(R[1, 0], R[1, 1])
             rpy[2] = math.atan2(R[0, 2], R[2, 2])
@@ -1526,16 +1613,12 @@ def tr2jac(T):
     R = base.t2r(T)
     return np.block([[R, Z], [Z, R]])
 
-def eul2jac(*angles):
+def eul2jac(angles):
     """
     Euler angle rate Jacobian
 
-    :param phi: Z-axis rotation
-    :type phi: float
-    :param theta: Y-axis rotation
-    :type theta: float
-    :param psi: Z-axis rotation
-    :type psi: float
+    :param angles: Euler angles (φ, θ, ψ)
+    :type angles: array_like(3)
     :return: Jacobian matrix
     :rtype: ndarray(3,3)
 
@@ -1561,7 +1644,7 @@ def eul2jac(*angles):
 
     :SymPy: supported
 
-    :seealso: :func:`rpy2jac`, :func:`eul2r`
+    :seealso: :func:`rpy2jac`, :func:`exp2jac`, :func:`rot2jac`
     """
 
     if len(angles) == 1:
@@ -1582,25 +1665,19 @@ def eul2jac(*angles):
         ])
 
 
-def rpy2jac(*angles, order='zyx'):
+def rpy2jac(angles, order='zyx'):
     """
     Jacobian from RPY angle rates to angular velocity
 
-    :param order: [description], defaults to 'zyx'
+    :param angles: roll-pitch-yaw angles (⍺, β, γ)
+    :param order: angle sequence, defaults to 'zyx'
     :type order: str, optional
-
-    :param roll: roll angle
-    :type roll: float
-    :param pitch: pitch angle
-    :type pitch: float
-    :param yaw: yaw angle
-    :type yaw: float
     :param order: rotation order: 'zyx' [default], 'xyz', or 'yxz'
     :type order: str
     :return: Jacobian matrix
     :rtype: ndarray(3,3)
 
-    - ``rpy2r(⍺, β, γ)`` is a Jacobian matrix (3x3) that maps roll-pitch-yaw angle 
+    - ``rpy2jac(⍺, β, γ)`` is a Jacobian matrix (3x3) that maps roll-pitch-yaw angle 
       rates to angular velocity at the operating point (⍺, β, γ).
       These correspond to successive rotations about the axes specified by
       ``order``:
@@ -1615,7 +1692,7 @@ def rpy2jac(*angles, order='zyx'):
           then by ⍺ about the new z-axis. Convention for a camera with z-axis
           parallel to the optic axis and x-axis parallel to the pixel rows.
 
-    - ``rpy2r(𝚪)`` as above but the roll, pitch, yaw angles are taken
+    - ``rpy2jac(𝚪)`` as above but the roll, pitch, yaw angles are taken
       from ``𝚪`` which is a 3-vector with values (⍺, β, γ).
 
     .. runblock:: pycon
@@ -1632,12 +1709,9 @@ def rpy2jac(*angles, order='zyx'):
 
     :SymPy: supported
 
-    :seealso: :func:`eul2jac`, :func:`rpy2r`
+    :seealso: :func:`eul2jac`, :func:`exp2jac`, :func:`rot2jac`
     """
     
-    if len(angles) == 1:
-        angles = angles[0]
-    
     pitch = angles[1]
     yaw = angles[2]
     
@@ -1667,7 +1741,318 @@ def rpy2jac(*angles, order='zyx'):
                 [ cp * cy, -sy, 0]
             ])
     return J
+
+def exp2jac(v):
+    """
+    Jacobian from exponential coordinate rates to angular velocity
+
+    :param v: Exponential coordinates
+    :type v: array_like(3)
+    :return: Jacobian matrix
+    :rtype: ndarray(3,3)
+
+    - ``exp2jac(v)`` is a Jacobian matrix (3x3) that maps exponential coordinate
+      rates to angular velocity at the operating point ``v``.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> expjac(0.3 * np.r_[1, 0, 0])
+
+    .. note::
+        - Used in the creation of an analytical Jacobian.
+
+    Reference::
+
+        - A compact formula for the derivative of a 3-D rotation in 
+          exponential coordinate
+          Guillermo Gallego, Anthony Yezzi
+          https://arxiv.org/pdf/1312.0788v1.pdf
+
+    :SymPy: supported
+
+    :seealso: :func:`eul2jac`, :func:`rpy2jac`, :func:`rot2jac`
+    """
+
+
+    vn, theta = base.unitvec_norm(v)
+    if theta is None:
+        return np.eye(3)
+
+    R = trexp(v)
+
+    z = np.eye(3,3) - R
+    A = []
+    for i in range(3):
+        dRdvi = vn[i] * base.skew(vn) + base.skew(np.cross(vn, z[:,i])) / theta
+        x = base.vex(dRdvi)
+        A.append(x)
+    return np.c_[A].T
+
+def rot2jac(R, representation='rpy-xyz'):
+    """
+    Velocity transform for analytical Jacobian
+
+    :param R: SO(3) rotation matrix
+    :type R: ndarray(3,3)
+    :param representation: defaults to 'rpy-xyz'
+    :type representation: str, optional
+    :return: Jacobian matrix
+    :rtype: ndarray(6,6)
+
+    Computes the transformation from spatial velocity :math:`\nu`, where
+    rotation rate is expressed as angular velocity, to analytical rates
+    :math:`\dvec{x}` where the rotational part is expressed as rate of change in
+    some other representation
+
+    .. math::
+        \dvec{x} = \mat{A} \vec{\nu}
+
+    where :math:`\mat{A}` is a block diagonal 6x6 matrix
+
+    ==================  ========================================
+    ``representation``  Rotational representation
+    ==================  ========================================
+    ``'rpy/xyz'``       RPY angular rates in XYZ order (default)
+    ``'rpy/zyx'``       RPY angular rates in XYZ order
+    ``'eul'``           Euler angular rates in ZYZ order
+    ``'exp'``           exponential coordinate rates
+    =================   ========================================
+
+    .. note:: Compared to :func:`eul2jac`, :func:`rpy2jac`, :func:`exp2jac`
+        - This performs the inverse mapping
+        - This maps a 6-vector, the others map a 3-vector
+
+    :seealso: :func:`eul2jac`, :func:`rpy2r`, :func:`exp2jac`
+    """
+
+    if ishom(R):
+        R = base.t2r(R)
     
+    # R = R.T
+
+    if representation == 'rpy/xyz':
+        rpy = tr2rpy(R, order='xyz')
+        A = rpy2jac(rpy, order='xyz')
+    elif representation == 'rpy/zyx':
+        rpy = tr2rpy(R, order='zyx')
+        A = rpy2jac(rpy, order='zyx')
+    elif representation == 'eul':
+        eul = tr2eul(R)
+        A = eul2jac(eul)
+    elif representation == 'exp':
+        (theta, v) = trlog(R)
+        A = exp2jac(v, theta)
+    else:
+        raise ValueError('bad representation specified')
+
+    return sp.linalg.block_diag(np.eye(3,3), np.linalg.inv(A))
+
+
+def angvelxform(𝚪, inverse=False, full=True, representation='rpy/xyz'):
+    """
+    Angular velocity transformation
+
+    :param 𝚪: angular representation
+    :type 𝚪: ndarray(3)
+    :param representation: defaults to 'rpy-xyz'
+    :type representation: str, optional
+    :param inverse: compute mapping from analytical rates to angular velocity
+    :type inverse: bool
+    :param full: return 6x6 transform for spatial velocity
+    :type full: bool
+    :return: angular velocity transformation matrix
+    :rtype: ndarray(6,6) or ndarray(3,3)
+
+    Computes the transformation from spatial velocity, where rotation rate is
+    expressed as angular velocity, to analytical rates where the rotational part
+    is expressed as rate of change in some other representation
+
+    Computes the transformation from spatial velocity :math:`\nu`, where
+    rotation rate is expressed as angular velocity, to analytical rates
+    :math:`\dvec{x}` where the rotational part is expressed as rate of change in
+    some other representation
+
+    .. math::
+        \dvec{x} = \mat{A} \vec{\nu}
+
+    where :math:`\mat{A}` is a block diagonal 6x6 matrix
+
+    ==================  ========================================
+    ``representation``  Rotational representation
+    ==================  ========================================
+    ``'rpy/xyz'``       RPY angular rates in XYZ order (default)
+    ``'rpy/zyx'``       RPY angular rates in XYZ order
+    ``'eul'``           Euler angular rates in ZYZ order
+    ``'exp'``           exponential coordinate rates
+    =================   ========================================
+
+    .. note:: Compared to :func:`eul2jac`, :func:`rpy2jac`, :func:`exp2jac`
+        - This performs the inverse mapping
+        - This maps a 6-vector, the others map a 3-vector
+
+https://ethz.ch/content/dam/ethz/special-interest/mavt/robotics-n-intelligent-systems/rsl-dam/documents/RobotDynamics2016/RD2016script.pdf
+    :seealso: :func:`rot2jac`, :func:`eul2jac`, :func:`rpy2r`, :func:`exp2jac`
+    """
+
+    if representation == 'rpy/xyz':
+        alpha = 𝚪[0]
+        beta = 𝚪[1]
+        gamma = 𝚪[2]
+        if inverse:
+            A = np.array([
+                [math.sin(beta), 0, 1], 
+                [-math.sin(gamma)*math.cos(beta), math.cos(gamma), 0], 
+                [math.cos(beta)*math.cos(gamma), math.sin(gamma), 0]
+                ])
+        else:
+            A = np.array([
+                [0, -math.sin(gamma)/math.cos(beta), math.cos(gamma)/math.cos(beta)], 
+                [0, math.cos(gamma), math.sin(gamma)], 
+                [1, math.sin(gamma)*math.tan(beta), -math.cos(gamma)*math.tan(beta)]
+                ])
+
+
+    elif representation == 'rpy/zyx':
+        alpha = 𝚪[0]
+        beta = 𝚪[1]
+        gamma = 𝚪[2]
+
+        if inverse:
+            A = np.array([
+                [math.cos(beta)*math.cos(gamma), -math.sin(gamma), 0], 
+                [math.sin(gamma)*math.cos(beta), math.cos(gamma), 0], 
+                [-math.sin(beta), 0, 1]
+                ])
+        else:
+            A = np.array([
+                [math.cos(gamma)/math.cos(beta), math.sin(gamma)/math.cos(beta), 0],
+                [-math.sin(gamma), math.cos(gamma), 0],
+                [math.cos(gamma)*math.tan(beta), math.sin(gamma)*math.tan(beta), 1]
+                ])
+
+    elif representation == 'eul':
+        phi = 𝚪[0]
+        theta = 𝚪[1]
+        psi = 𝚪[2]
+
+        if inverse:
+            A = np.array([
+                [0, -math.sin(phi), math.sin(theta)*math.cos(phi)], 
+                [0, math.cos(phi), math.sin(phi)*math.sin(theta)], 
+                [1, 0, math.cos(theta)]
+                ])
+        else:
+            A = np.array([
+                [-math.cos(phi)/math.tan(theta), -math.sin(phi)/math.tan(theta), 1], 
+                [-math.sin(phi), math.cos(phi), 0], 
+                [math.cos(phi)/math.sin(theta), math.sin(phi)/math.sin(theta), 0]
+                ])
+    elif representation == 'exp':
+        raise UserWarning('not implemented yet')
+    else:
+        raise ValueError('bad representation specified')
+
+    if full:
+        return sp.linalg.block_diag(np.eye(3,3), A)
+    else:
+        return A
+
+def angvelxform_dot(𝚪, 𝚪d, full=True, representation='rpy/xyz'):
+    """
+    Angular acceleratipn transformation
+
+    :param 𝚪: angular representation
+    :type 𝚪: ndarray(3)
+    :param 𝚪d: angular representation rate
+    :type 𝚪d: ndarray(3)
+    :param representation: defaults to 'rpy-xyz'
+    :type representation: str, optional
+    :param full: return 6x6 transform for spatial velocity
+    :type full: bool
+    :return: angular velocity transformation matrix
+    :rtype: ndarray(6,6) or ndarray(3,3)
+
+    Computes the transformation from spatial velocity, where rotation rate is
+    expressed as angular velocity, to analytical rates where the rotational part
+    is expressed as rate of change in some other representation
+
+    Computes the transformation from spatial velocity :math:`\nu`, where
+    rotation rate is expressed as angular velocity, to analytical rates
+    :math:`\dvec{x}` where the rotational part is expressed as rate of change in
+    some other representation
+
+    .. math::
+        \ddvec{x} = \mat{A}_d \dvec{\nu}
+
+    where :math:`\mat{A}_d` is a block diagonal 6x6 matrix
+
+    ==================  ========================================
+    ``representation``  Rotational representation
+    ==================  ========================================
+    ``'rpy/xyz'``       RPY angular rates in XYZ order (default)
+    ``'rpy/zyx'``       RPY angular rates in XYZ order
+    ``'eul'``           Euler angular rates in ZYZ order
+    ``'exp'``           exponential coordinate rates
+    =================   ========================================
+
+    .. note:: Compared to :func:`eul2jac`, :func:`rpy2jac`, :func:`exp2jac`
+        - This performs the inverse mapping
+        - This maps a 6-vector, the others map a 3-vector
+
+https://ethz.ch/content/dam/ethz/special-interest/mavt/robotics-n-intelligent-systems/rsl-dam/documents/RobotDynamics2016/RD2016script.pdf
+    :seealso: :func:`rot2jac`, :func:`eul2jac`, :func:`rpy2r`, :func:`exp2jac`
+    """
+
+    if representation == 'rpy/xyz':
+        alpha = 𝚪[0]
+        beta = 𝚪[1]
+        gamma = 𝚪[2]
+        alpha_dot = 𝚪d[0]
+        beta_dot = 𝚪d[1]
+        gamma_dot = 𝚪d[2]
+        Ad = np.array([
+            [0, -(beta_dot*math.sin(beta)*math.sin(gamma)/math.cos(beta) + gamma_dot*math.cos(gamma))/math.cos(beta), (beta_dot*math.sin(beta)*math.cos(gamma)/math.cos(beta) - gamma_dot*math.sin(gamma))/math.cos(beta)], 
+            [0, -gamma_dot*math.sin(gamma), gamma_dot*math.cos(gamma)], 
+            [0, beta_dot*math.sin(gamma)/math.cos(beta)**2 + gamma_dot*math.cos(gamma)*math.tan(beta), -beta_dot*math.cos(gamma)/math.cos(beta)**2 + gamma_dot*math.sin(gamma)*math.tan(beta)]
+            ])
+
+    elif representation == 'rpy/zyx':
+        alpha = 𝚪[0]
+        beta = 𝚪[1]
+        gamma = 𝚪[2]
+        alpha_dot = 𝚪d[0]
+        beta_dot = 𝚪d[1]
+        gamma_dot = 𝚪d[2]
+        Ad = np.array([
+            [(beta_dot*math.sin(beta)*math.cos(gamma)/math.cos(beta) - gamma_dot*math.sin(gamma))/math.cos(beta), (beta_dot*math.sin(beta)*math.sin(gamma)/math.cos(beta) + gamma_dot*math.cos(gamma))/math.cos(beta), 0], 
+            [-gamma_dot*math.cos(gamma), -gamma_dot*math.sin(gamma), 0], 
+            [beta_dot*math.cos(gamma)/math.cos(beta)**2 - gamma_dot*math.sin(gamma)*math.tan(beta), beta_dot*math.sin(gamma)/math.cos(beta)**2 + gamma_dot*math.cos(gamma)*math.tan(beta), 0]
+            ])
+
+    elif representation == 'eul':
+        phi = 𝚪[0]
+        theta = 𝚪[1]
+        psi = 𝚪[2]
+        phi_dot = 𝚪d[0]
+        theta_dot = 𝚪d[1]
+        psi_dot = 𝚪d[2]
+        A = np.array([
+            [phi_dot*math.sin(phi)/math.tan(theta) + theta_dot*math.cos(phi)/math.sin(theta)**2, -phi_dot*math.cos(phi)/math.tan(theta) + theta_dot*math.sin(phi)/math.sin(theta)**2, 0], 
+            [-phi_dot*math.cos(phi), -phi_dot*math.sin(phi), 0], 
+            [-(phi_dot*math.sin(phi) + theta_dot*math.cos(phi)*math.cos(theta)/math.sin(theta))/math.sin(theta), (phi_dot*math.cos(phi) - theta_dot*math.sin(phi)*math.cos(theta)/math.sin(theta))/math.sin(theta), 0]
+            ])
+    
+    elif representation == 'exp':
+        raise UserWarning('not implemented yet')
+    else:
+        raise ValueError('bad representation specified')
+
+    if full:
+        return sp.linalg.block_diag(np.eye(3,3), A)
+    else:
+        return A
+
 def tr2adjoint(T):
     r"""
     SE(3) adjoint matrix
@@ -1716,7 +2101,7 @@ def tr2adjoint(T):
         raise ValueError('bad argument')
         
 
-def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', degsym=True, unit='deg'):
+def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:.3g}', degsym=True, unit='deg'):
     """
     Compact display of SO(3) or SE(3) matrices
 
@@ -1728,7 +2113,7 @@ def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', deg
     :type orient: str
     :param file: file to write formatted string to. [default, stdout]
     :type file: file object
-    :param fmt: conversion format for each number
+    :param fmt: conversion format for each number in the format used with ``format``
     :type fmt: str
     :param unit: angular units: 'rad' [default], or 'deg'
     :type unit: str
@@ -1739,16 +2124,19 @@ def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', deg
     The matrix is formatted and written to ``file`` and the
     string is returned.  To suppress writing to a file, set ``file=None``.
 
-   - ``trprint(R)`` displays the SO(3) rotation matrix in a compact
+   - ``trprint(R)`` prints the SO(3) rotation matrix to stdout in a compact
       single-line format:
 
         [LABEL:] ORIENTATION UNIT
 
-    - ``trprint(T)`` displays the SE(3) homogoneous transform in a compact
-      single-line format:
+    - ``trprint(T)`` prints the SE(3) homogoneous transform to stdout in a
+      compact single-line format:
 
         [LABEL:] [t=X, Y, Z;] ORIENTATION UNIT
 
+    - ``trprint(X, file=None)`` as above but returns the string rather than 
+      printing to a file
+
     Orientation is expressed in one of several formats:
 
     - 'rpy/zyx' roll-pitch-yaw angles in ZYX axis order [default]
@@ -1771,7 +2159,9 @@ def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', deg
         - If the 'rpy' option is selected, then the particular angle sequence can be
           specified with the options 'xyz' or 'yxz' which are passed through to ``tr2rpy``.
           'zyx' is the default.
-        - Default formatting is for readable columns of data
+        - Default formatting is for compact display of data
+        - For tabular data set ``fmt`` to a fixed width format such as
+          ``fmt='{:.3g}'``
 
     :seealso: :func:`~spatialmath.base.transforms2d.trprint2`, :func:`~tr2eul`, :func:`~tr2rpy`, :func:`~tr2angvec`
     :SymPy: not supported
@@ -1825,7 +2215,7 @@ def trprint(T, orient='rpy/zyx', label=None, file=sys.stdout, fmt='{:8.2g}', deg
 
 
 def _vec2s(fmt, v):
-    v = [x if np.abs(x) > 100 * _eps else 0.0 for x in v]
+    v = [x if np.abs(x) > 1e-6 else 0.0 for x in v]
     return ', '.join([fmt.format(x) for x in v])
 
 
