@@ -8,9 +8,9 @@ from spatialmath.pose3d import SO3, SE3
 from spatialmath.pose2d import SE2
 from spatialmath.geom3d import Plucker
 import spatialmath.base as base
-from spatialmath.smuserlist import SMUserList
+from spatialmath.baseposelist import BasePoseList
 
-class SMTwist(SMUserList):
+class BaseTwist(BasePoseList):
     """
     Superclass for 3D and 2D twist objects
 
@@ -303,7 +303,7 @@ class SMTwist(SMUserList):
 # ======================================================================== #
 
 
-class Twist3(SMTwist):
+class Twist3(BaseTwist):
     r"""
     3D twist class
 
@@ -341,15 +341,18 @@ class Twist3(SMTwist):
 
         if w is None:
             # zero or one arguments passed
-            if super().arghandler(arg, convertfrom=(SE3,), check=check):
+            if super().arghandler(arg, check=check):
                 return
+            elif isinstance(arg, SE3):
+                self.data = [arg.twist().A]
 
         elif w is not None and base.isvector(w, 3) and base.isvector(arg,3):
             # Twist(v, w)
             self.data = [np.r_[arg, w]]
             return
 
-        raise ValueError('bad twist value')
+        else:
+            raise ValueError('bad value to Twist constructor')
             
     # ------------------------ SMUserList required ---------------------------#
 
@@ -1072,7 +1075,7 @@ class Twist3(SMTwist):
 
 # ======================================================================== #
 
-class Twist2(SMTwist):
+class Twist2(BaseTwist):
 
     def __init__(self, arg=None, w=None, check=True):
         r"""
@@ -1564,8 +1567,8 @@ class Twist2(SMTwist):
 
 if __name__ == '__main__':   # pragma: no cover
 
+    tw = Twist3( SE3.Rx(0) )
 
+    # import pathlib
 
-    import pathlib
-
-    exec(open(pathlib.Path(__file__).parent.parent.absolute() / "tests" / "test_twist.py").read())  # pylint: disable=exec-used
\ No newline at end of file
+    # exec(open(pathlib.Path(__file__).parent.parent.absolute() / "tests" / "test_twist.py").read())  # pylint: disable=exec-used
\ No newline at end of file
